pub trait ReadWriteSeek:
Read
+ Write
+ Seek { }Expand description
Combined trait for types that implement Read, Write, and Seek.
This trait is automatically implemented for all types that implement all three
traits, enabling their use as trait objects (&mut dyn ReadWriteSeek) for
writer-based saving without requiring a filesystem path.
Common implementors include std::io::Cursor<Vec<u8>> and std::fs::File.